import React, { useState } from 'react';
import { Button, Tooltip, TooltipContent, TooltipProvider, TooltipTrigger } from '../components';
import { Addchart, Schema as SchemaIcon, Search as SearchIcon } from '@mui/icons-material';
import Schema from '../schema/panel';
import Searchbar from './search/searchbar';
import Settings from './settings';
import ColorMode from '../components/color-mode';

export default function InfoPanel({ auth, manager }: { auth: boolean; manager: any }) {
  const [tab, setTab] = useState('Schema');

  return (
    <div className="info-panel w-full h-full flex">
      <div className="w-12 flex flex-col items-center justify-between">
        <div>
          <TooltipProvider delayDuration={100}>
            <Tooltip>
              <TooltipTrigger>
                <Button
                  type="secondary"
                  variant="ghost"
                  size="md"
                  iconComponent={<SearchIcon />}
                  onClick={() => setTab('Search')}
                  additionalClasses={tab === 'Search' ? 'bg-secondary-100' : ''}
                />
              </TooltipTrigger>
              <TooltipContent side={'right'}>Search</TooltipContent>
            </Tooltip>
            <Tooltip>
              <TooltipTrigger>
                <Button
                  type="secondary"
                  variant="ghost"
                  size="md"
                  iconComponent={<SchemaIcon />}
                  onClick={() => setTab('Schema')}
                  additionalClasses={tab === 'Schema' ? 'bg-secondary-100' : ''}
                />
              </TooltipTrigger>
              <TooltipContent side={'right'}>Database schema</TooltipContent>
            </Tooltip>
            <Tooltip>
              <TooltipTrigger>
                <Button
                  type="secondary"
                  variant="ghost"
                  size="md"
                  iconComponent={<Addchart />}
                  onClick={() => setTab('Visualization')}
                  additionalClasses={tab === 'Visualization' ? 'bg-secondary-100' : ''}
                />
              </TooltipTrigger>
              <TooltipContent side={'right'}>Visualization settings</TooltipContent>
            </Tooltip>
          </TooltipProvider>
        </div>
        <ColorMode />
      </div>
      <div className="flex-1 border border-secondary-200 overflow-hidden">
        <div className="relative flex items-center justify-between z-[2] py-0 px-2 bg-secondary-100  border-b border-secondary-200">
          <h1 className="text-xs font-semibold text-secondary-800">{tab}</h1>
        </div>
        {tab === 'Search' && <Searchbar />}
        {tab === 'Schema' && <Schema auth={auth} />}
        {tab === 'Visualization' && <Settings manager={manager} />}
      </div>
    </div>
  );
}
