export type Coordinate = [number, number] | [];

export interface LayerProps {
  [key: string]: any;
}

export interface GeoJSONData {
  type: string;
  features: any[];
}

export type Layer = {
  id: number;
  name: string;
  type: any;
  config: any;
  visible: boolean;
};

export type GraphType = {
  getNode(id: string): Node | null;
  getNodes(): Node[];
  getNodeLocation(id: string): Coordinate | null;
  getEdge(id: string): Edge | null;
  getEdges(): Edge[];
  consumeMessageFromBackend(queryResult: { nodes: Node[]; edges: Edge[] }): void;
  getGraphInfo(): {
    nodeAttributes: { [attribute: string]: any };
    edgeAttributes: { [attribute: string]: any };
  };
};

export type GeoNode = {
  id: string;
  attributes: {
    long: number;
    lat: number;
    [key: string]: any;
  };
  connectedEdges: string[];
  [key: string]: any;
};

export type Node = {
  id: string;
  attributes: {
    long: number;
    lat: number;
    [key: string]: any;
  };
  connectedEdges: string[];
  [key: string]: any;
};

export type GeoEdge = {
  id: string;
  from: string;
  to: string;
  attributes: {
    [key: string]: any;
  };
  [key: string]: any;
};

export type Edge = {
  id: string;
  from: string;
  to: string;
  attributes: {
    [key: string]: any;
  };
  [key: string]: any;
};
